export const writeCookie = (item, value, { maxAge, expires, secure = false } = {}) => {
  const cookieData = {
    [item]: value,
    domain: `*.${location.hostname}`,
    path: '/',
    secure
  };

  if (location.hostname === 'localhost') {
    cookieData.domain = 'localhost';
    cookieData.secure = false;
  }

  if (maxAge) {
    cookieData['max-age'] = Math.floor(maxAge / 1000); // convert to seconds
  } else if (expires) {
    cookieData.expires = expires.toGMTString();
  }

  const cookieString = Object.keys(cookieData).reduce((result, key) => {
    const value = cookieData[key];
    if (typeof value === 'boolean') {
      if (value === true) {
        result.push(key);
      }
    } else {
      result.push(`${key}=${value}`);
    }
    return result;
  }, []).join(';');

  document.cookie = cookieString;
};

export const readCookie = name => {
  const { cookie } = document;
  let res;
  const setPos = cookie.search(new RegExp('\\b' + name + '='));
  const stopPos = cookie.indexOf(';', setPos);

  if (!~setPos) return null;
  res = decodeURIComponent(cookie.substring(setPos, ~stopPos ? stopPos : undefined).split('=')[1]);
  return res;
};

export const deleteCookie = item => writeCookie(item, '', { expires: new Date(0) });